==> haskell-doctemplates-0.2.2.1-79-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doctemplates
version: 0.2.2.1
id: doctemplates-0.2.2.1-LKJRzW7HED921jFXDeeXOQ
key: doctemplates-0.2.2.1-LKJRzW7HED921jFXDeeXOQ
license: BSD-3-Clause
copyright: 2016 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: https://github.com/jgm/doctemplates#readme
synopsis: Pandoc-style document templates
description:
    A simple text templating system used by pandoc.
category: Text
abi: 4f087ff548c1b730665490c206e4c3fe
exposed: True
exposed-modules:
    Text.DocTemplates
import-dirs: /usr/lib/ghc-8.6.5/site-local/doctemplates-0.2.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/doctemplates-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-doctemplates
hs-libraries: HSdoctemplates-0.2.2.1-LKJRzW7HED921jFXDeeXOQ
depends:
    aeson-1.4.3.0-BTVTAPf4Xo575Po56SJ3Aq base-4.12.0.0
    blaze-html-0.9.1.1-F1eLxc08jYH7pUMZdB1tmO
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    containers-0.6.0.1 parsec-3.1.13.0
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    unordered-containers-0.2.10.0-2N7l4ZvxBr3HGayD0s0P1Q
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock
haddock-html: /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctemplates-0.2.2.1-80-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doctemplates
version: 0.2.2.1
id: doctemplates-0.2.2.1-KJ5sQUxX9OBGDbVkN2Vk5k
key: doctemplates-0.2.2.1-KJ5sQUxX9OBGDbVkN2Vk5k
license: BSD-3-Clause
copyright: 2016 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: https://github.com/jgm/doctemplates#readme
synopsis: Pandoc-style document templates
description:
    A simple text templating system used by pandoc.
category: Text
abi: 7b4b05b57b2ce8134aff0c2892c03a3d
exposed: True
exposed-modules:
    Text.DocTemplates
import-dirs: /usr/lib/ghc-8.6.5/site-local/doctemplates-0.2.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/doctemplates-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-doctemplates
hs-libraries: HSdoctemplates-0.2.2.1-KJ5sQUxX9OBGDbVkN2Vk5k
depends:
    aeson-1.4.3.0-3QzK2ng22UC3SLyLfNCRqk base-4.12.0.0
    blaze-html-0.9.1.1-6PAyIvh6hy6Ilt6w0CbPFV
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    containers-0.6.0.1 parsec-3.1.13.0
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    unordered-containers-0.2.10.0-FCaPs5fnhYpFgvItTiMoQE
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock
haddock-html: /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
